
Welcome to pdsimage
===================

The Lunar Reconnaissance Orbiter  (`LRO`_) mission has gathered some
fantastic data of the lunar surface  and, thanks to `NASA`_, all are
available for free on the internet.

However,  using them  can  be  criptic without  a  bit of  experience.
**Pdsimage** aims  to facilitate the  extraction of knowledge  from two
set of data gathered by two experiments on board of LRO:

   - The Lunar Orbiter Laser Altimer (`LOLA`_) experiment which
     collected high resolution topographic data of the lunar surface 
   - The  Lunar  Reconnaissance  Orbiter Camera  (`LROC`_)  experiment
     which collected  images of the  lunar surface. In  particular, we
     focus  on Wide  Angle Images  taken  from the  Wide Angle  Camera
     (`WAC`_)


Highlighted features
------------------------

Unlike  previous python  PDS  library, this  module  allows to  easily
extract data for arbitrarily sized region at the lunar surface.

It is particularly suited for  studying geological unit at the surface
of the  Moon.  It also  includes some extension  to ease the  study of
lunar impact craters and low-slope domes.

FULL DOCUMENTATION `HERE`_

.. _HERE:
    http://pdsimage.readthedocs.org/

.. _NASA:
    https://pds.nasa.gov/

.. _LOLA:
    http://lunar.gsfc.nasa.gov/lola/

.. _LRO:
    http://www.nasa.gov/mission_pages/LRO/main/index.html

.. _LROC:
    http://lroc.sese.asu.edu/about
    
.. _WAC:
    http://lroc.sese.asu.edu/images
        
